.. include:: references.txt

*****************
How to contribute
*****************

We welcome contributions from anyone via pull requests on `GitHub
<https://github.com/adrn/gala>`_. If you don't feel comfortable modifying or
adding functionality, we also welcome feature requests and bug reports as
`GitHub issues <https://github.com/adrn/gala/issues>`_.

Developer documentation
=======================

.. toctree::
    :maxdepth: 1

    testing
    docs
